@@ -1,6 +1,6 @@
 package Email::MIME::Kit::Assembler::Markdown;
 # ABSTRACT: build multipart/alternative messages from Markdown alone
-$Email::MIME::Kit::Assembler::Markdown::VERSION = '0.100003';
+$Email::MIME::Kit::Assembler::Markdown::VERSION = '0.100004';
 use Moose;
 with 'Email::MIME::Kit::Role::Assembler';
 
@@ -56,6 +56,12 @@ use Text::Markdown;
 #pod breaks.  The specific munging performed is not guaranteed to remain exactly
 #pod stable.
 #pod
+#pod If given (and true), the C<render_wrapper> option will cause the kit entry to
+#pod be passed through the renderer named in the kit. That is to say, the kit entry
+#pod is a template. In this case, the C<marker> comment is ignored. Instead, the
+#pod wrapped content (Markdown-produced HTML or text) is available in a template
+#pod parameter called C<wrapped_content>, and should be included that way.
+#pod
 #pod =cut
 
 has manifest => (
@@ -79,6 +85,12 @@ has munge_signature => (
   default => 0,
 );
 
+has render_wrapper => (
+  is      => 'ro',
+  isa     => 'Bool',
+  default => 0,
+);
+
 has renderer => (
   reader   => 'renderer',
   writer   => '_set_renderer',
@@ -171,14 +183,21 @@ sub assemble {
 
     if (my $wrapper_path = $self->$type_wrapper) {
       my $wrapper = ${ $self->kit->get_decoded_kit_entry($wrapper_path) };
-      my $marker  = $self->marker;
-      my $marker_re = qr{<!--\s+\Q$marker\E\s+-->};
 
-      confess "$type_wrapper does not contain comment containing marker"
-        unless $wrapper =~ $marker_re;
+      if ($self->render_wrapper) {
+        $stash->{wrapped_content} = $content{$type};
+        my $output_ref = $self->renderer->render(\$wrapper, $stash);
+        $content{$type} = $$output_ref;
+      } else {
+        my $marker  = $self->marker;
+        my $marker_re = qr{<!--\s+\Q$marker\E\s+-->};
 
-      $wrapper =~ s/$marker_re/$content{$type}/;
-      $content{$type} = $wrapper;
+        confess "$type_wrapper does not contain comment containing marker"
+          unless $wrapper =~ $marker_re;
+
+        $wrapper =~ s/$marker_re/$content{$type}/;
+        $content{$type} = $wrapper;
+      }
     }
   }
 
@@ -231,7 +250,7 @@ Email::MIME::Kit::Assembler::Markdown - build multipart/alternative messages fro
 
 =head1 VERSION
 
-version 0.100003
+version 0.100004
 
 =head1 SYNOPSIS
 
@@ -279,15 +298,37 @@ munging of a sigdash-prefixed signature in the source text, hardening line
 breaks.  The specific munging performed is not guaranteed to remain exactly
 stable.
 
+If given (and true), the C<render_wrapper> option will cause the kit entry to
+be passed through the renderer named in the kit. That is to say, the kit entry
+is a template. In this case, the C<marker> comment is ignored. Instead, the
+wrapped content (Markdown-produced HTML or text) is available in a template
+parameter called C<wrapped_content>, and should be included that way.
+
 =for Pod::Coverage assemble BUILD
 
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Chris Nehren Robert Norris
+
+=over 4
+
+=item *
+
+Chris Nehren <cnehren@gmail.com>
+
+=item *
+
+Robert Norris <rob@eatenbyagrue.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2016 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
